package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````@"$```````!``````````)"A````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0````````````````````````````````````B;````````")L`````````
M``$```````$````&````")L````````(FP$```````B;`0``````>`4`````
M``"@%0```````````0```````@````8````8FP```````!B;`0``````&)L!
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````!)0````````$E`````````24````````_`````````#\``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!`````B;````````")L!```````(FP$`
M`````/@$````````^`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`<K@MJ%.Y"G_G>#QSY5];&\,N
M(<P$````$`````$```!'3E4```````,````'`````````!$```!*````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(@!!!N@`""$H```!+````
M3@```%(```!3````6P```%P```!=`````````%\```!@````80```&(```!C
M````9@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````
M`````````````````````````````````P`+`#@;````````````````````
M`````P`6``"@`0`````````````````H`@``$@``````````````````````
M``#8````$@````````````````````````#%`@``$@``````````````````
M``````#N````$0`````````````````````````/`@``$@``````````````
M``````````"B`@``$@````````````````````````"2`0``$@``````````
M``````````````#<`0``$@`````````````````````````!````(```````
M```````````````````Y`0``$@````````````````````````!V`0``$@``
M``````````````````````"T`P``$@````````````````````````!:`@``
M$@````````````````````````#R`@``$0````````````````````````"U
M`@``$@````````````````````````!]`0``$@``````````````````````
M``!8`0``$@````````````````````````!N`0``$@``````````````````
M``````!C`@``$@````````````````````````"Y````$@``````````````
M``````````!&````(@`````````````````````````0````(```````````
M``````````````"U`0``$@````````````````````````!``@``$@``````
M```````````````````L````(`````````````````````````#?````$@``
M``````````````````````":````$@````````````````````````"C````
M$@````````````````````````"J````$@````````````````````````"&
M`@``$0````````````````````````!G````$@``````````````````````
M```R`@``$@`````````````````````````-`0``$@``````````````````
M``````#+`0``$@````````````````````````#H````$@``````````````
M```````````H`0``$@````````````````````````!+`@``$@``````````
M``````````````"N`0``$@````````````````````````!U`@``$@``````
M``````````````````!M````$@````````````````````````"J`@``$@``
M``````````````````````"-`@``$@````````````````````````!)`0``
M$@````````````````````````!_````$@`````````````````````````:
M`@``$@`````````````````````````(`@``$@``````````````````````
M``#F`@``$@````````````````````````"B````$@``````````````````
M``````"9`0``$@````````````````````````#Y````$@``````````````
M``````````"@`0``$@````````````````````````"Q````$@``````````
M``````````````"+`0``$@````````````````````````#1`@``$@``````
M``````````````````"$`0``$@````````````````````````#\`0``$@``
M``````````````````````!O`@``$@````````````````````````!"`0``
M$@````````````````````````#O`0``$0`````````````````````````M
M`@``$@`````````````````````````=`0``$@``````````````````````
M``"\`0``$@````````````````````````!F`0``$@``````````````````
M``````"O`@``$@````````````````````````!5````$@``````````````
M``````````"0````$0````````````````````````";`@``$@``````````
M``````````````##````$@````````````````````````#*````$@``````
M``````````````````"2````$0````````````````````````!H`@``$@``
M```````````````````````/!```$``7`*BP`0````````````````"]`P``
M$@`-`,1%````````-`$````````T!```$@`-`*1)````````@`<```````!B
M````$@`-`$`?````````)`(````````T`P``$@`-```[````````!```````
M``!2`P``$@`-`"11````````;`(```````#E`P``$``7`("@`0``````````
M``````!:!```$@`-``0[````````'`(````````:!```$``7`("@`0``````
M``````````!%`P``$@`-`"`]````````*`````````!H`P``$@`-`)1#````
M````D`````````#)`P``$0`/`+!3````````!`````````#S`P``$@`-``!'
M````````"`$```````#^`P``$@`-`.`Y````````.``````````&!```$``7
M`*BP`0`````````````````O!```$``7`*BP`0````````````````!(!```
M$@`-`$1$````````+`$```````#8`P``$``6``"@`0````````````````",
M`P``$@`-`%`]````````&`$```````!!!```$``6`("@`0``````````````
M``!G!```$0`6`'B@`0``````"`````````#>`P``$@`-`(`A````````-```
M```````F!```$@`-`'!%````````5`````````#:`P``(``6``"@`0``````
M``````````"B`P``$@`-`"1$````````(`````````!V`P``$@`-`"`Z````
M````X`````````"8`P``$@`-`!!(````````E`$````````.!```$``7`*BP
M`0````````````````!Q!```$@`-`'`^````````)`4`````````7U]G;6]N
M7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]C>&%?9FEN86QI>F4`7U]L:6)C7W-T87)T
M7VUA:6X`86)O<G0`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I
M;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E
M861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`
M<FUD:7(`4$Q?=&AR7VME>0!P=&AR96%D7V=E='-P96-I9FEC`&)O;W1?1'EN
M84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`
M;65M8VAR`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T<'8`;65M;6]V90!R
M96%L;&]C`&=E='!I9`!M96UC<'D`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R
M8VUP`%]?<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`%!E<FQ?871F;W)K7W5N;&]C:P!03%]D;U]U
M;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T
M<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?
M8V]N<W1R=6-T`'!E<FQ?<G5N`&5X:70`;65M<V5T`&UK9&ER`%]?97)R;F]?
M;&]C871I;VX`<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`
M<F5A9`!C;&]S90!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`7U]S=&%C:U]C:&M?9W5A<F0`
M;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!L9"UL:6YU>"UA87)C:#8T+G-O
M+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`
M7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S
M<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I
M<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A
M<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-P!'3$E"0U\R+C,T`$=,24)#
M7S(N,S,```````````$``@`!``$``0`"``(``0`!``(``@`"``$``P`!``(`
M`0`"``(``@`"``$``@`!``$``@`"``0``@`"``(``0`!``$``@`!``$``@`"
M``(``@`"``$``@`!``(``0`$``(`!0`"``(``@`!``(``0`"``(``0`"``$`
M`0`"``(`!0`"``(``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`'@,``!``
M```@````EY&6!@```P!^!`````````$``P`4`P``$`````````"TD98&```%
M`(D$```0````LY&6!@``!`"4!```$````)>1E@8```(`?@0````````(FP$`
M``````,$````````D"(````````0FP$```````,$````````0"(```````!`
MGP$```````,$````````)%$```````"(GP$```````,$````````>*`!````
M``"8GP$```````,$````````0!\````````(H`$```````,$````````"*`!
M```````8H`$```````,$````````R),````````@H`$```````,$````````
M(%0````````PH`$```````,$````````$%4````````XH`$```````,$````
M````J),```````!`H`$```````,$````````L),```````!(H`$```````,$
M````````N),```````!0H`$```````,$````````P),```````!@H`$`````
M``,$````````D),```````!HH`$```````,$````````F),```````!XH`$`
M``````,$````````.%<````````HGP$```````$$```&```````````````P
MGP$```````$$```*```````````````XGP$```````$$```+````````````
M``!(GP$```````$$```0``````````````!0GP$```````$$```7````````
M``````!8GP$```````$$```8``````````````!@GP$```````$$```;````
M``````````!HGP$```````$$```@``````````````!PGP$```````$$```C
M``````````````!XGP$```````$$```D``````````````"`GP$```````$$
M```]``````````````"0GP$```````$$``!(``````````````!`G0$`````
M``($```#``````````````!(G0$```````($```$``````````````!0G0$`
M``````($```%``````````````!8G0$```````($```'``````````````!@
MG0$```````($```(``````````````!HG0$```````($```)````````````
M``!PG0$```````($```+``````````````!XG0$```````($```,````````
M``````"`G0$```````($```-``````````````"(G0$```````($```.````
M``````````"0G0$```````($```/``````````````"8G0$```````($```1
M``````````````"@G0$```````($```2``````````````"HG0$```````($
M```3``````````````"PG0$```````($```4``````````````"XG0$`````
M``($```5``````````````#`G0$```````($```6``````````````#(G0$`
M``````($```7``````````````#0G0$```````($```9``````````````#8
MG0$```````($```:``````````````#@G0$```````($```<````````````
M``#HG0$```````($```=``````````````#PG0$```````($```>````````
M``````#XG0$```````($```?````````````````G@$```````($```A````
M```````````(G@$```````($```B```````````````0G@$```````($```E
M```````````````8G@$```````($```F```````````````@G@$```````($
M```G```````````````HG@$```````($```H```````````````PG@$`````
M``($```I```````````````XG@$```````($```J``````````````!`G@$`
M``````($```K``````````````!(G@$```````($```L``````````````!0
MG@$```````($```M``````````````!8G@$```````($```N````````````
M``!@G@$```````($```O``````````````!HG@$```````($```P````````
M``````!PG@$```````($```Q``````````````!XG@$```````($```R````
M``````````"`G@$```````($```S``````````````"(G@$```````($```T
M``````````````"0G@$```````($```U``````````````"8G@$```````($
M```V``````````````"@G@$```````($```W``````````````"HG@$`````
M``($```X``````````````"PG@$```````($```Y``````````````"XG@$`
M``````($```Z``````````````#`G@$```````($```[``````````````#(
MG@$```````($```\``````````````#0G@$```````($```^````````````
M``#8G@$```````($```_``````````````#@G@$```````($``!`````````
M``````#HG@$```````($``!!``````````````#PG@$```````($``!"````
M``````````#XG@$```````($``!#````````````````GP$```````($``!%
M```````````````(GP$```````($``!&```````````````0GP$```````($
M``!'```````````````8GP$```````($``!)```````````````?(`/5_7N_
MJ?T#`)&<`0"4_7O!J,`#7];P>[^IT```D!&>1OD0XC21(`(?UA\@`]4?(`/5
M'R`#U=```)`1HD;Y$`(UD2`"'];0``"0$:9&^1`B-9$@`A_6T```D!&J1OD0
M0C61(`(?UM```)`1KD;Y$&(UD2`"'];0``"0$;)&^1""-9$@`A_6T```D!&V
M1OD0HC61(`(?UM```)`1ND;Y$,(UD2`"'];0``"0$;Y&^1#B-9$@`A_6T```
MD!'"1OD0`C:1(`(?UM```)`1QD;Y$"(VD2`"'];0``"0$<I&^1!"-I$@`A_6
MT```D!'.1OD08C:1(`(?UM```)`1TD;Y$((VD2`"'];0``"0$=9&^1"B-I$@
M`A_6T```D!':1OD0PC:1(`(?UM```)`1WD;Y$.(VD2`"'];0``"0$>)&^1`"
M-Y$@`A_6T```D!'F1OD0(C>1(`(?UM```)`1ZD;Y$$(WD2`"'];0``"0$>Y&
M^1!B-Y$@`A_6T```D!'R1OD0@C>1(`(?UM```)`1]D;Y$*(WD2`"'];0``"0
M$?I&^1#"-Y$@`A_6T```D!'^1OD0XC>1(`(?UM```)`1`D?Y$`(XD2`"'];0
M``"0$09'^1`B.)$@`A_6T```D!$*1_D00CB1(`(?UM```)`1#D?Y$&(XD2`"
M'];0``"0$1)'^1"".)$@`A_6T```D!$61_D0HCB1(`(?UM```)`1&D?Y$,(X
MD2`"'];0``"0$1Y'^1#B.)$@`A_6T```D!$B1_D0`CF1(`(?UM```)`1)D?Y
M$"(YD2`"'];0``"0$2I'^1!".9$@`A_6T```D!$N1_D08CF1(`(?UM```)`1
M,D?Y$((YD2`"'];0``"0$39'^1"B.9$@`A_6T```D!$Z1_D0PCF1(`(?UM``
M`)`1/D?Y$.(YD2`"'];0``"0$4)'^1`".I$@`A_6T```D!%&1_D0(CJ1(`(?
MUM```)`12D?Y$$(ZD2`"'];0``"0$4Y'^1!B.I$@`A_6T```D!%21_D0@CJ1
M(`(?UM```)`15D?Y$*(ZD2`"'];0``"0$5I'^1#".I$@`A_6T```D!%>1_D0
MXCJ1(`(?UM```)`18D?Y$`([D2`"'];0``"0$69'^1`B.Y$@`A_6T```D!%J
M1_D00CN1(`(?UM```)`1;D?Y$&([D2`"'];0``"0$7)'^1"".Y$@`A_6T```
MD!%V1_D0HCN1(`(?UM```)`1>D?Y$,([D2`"'];0``"0$7Y'^1#B.Y$@`A_6
MT```D!&"1_D0`CR1(`(?UM```)`1AD?Y$"(\D2`"'];0``"0$8I'^1!"/)$@
M`A_6T```D!&.1_D08CR1(`(?U@````````````````````#]>[JIPP``D/T#
M`)%CI$?Y\U,!J?5;`JGBAP.IXN,`D>$#`9'@3P"YX#,!D60`0/GD+P#Y!`"`
MTL[__Y?```"0P@``D`"\1_E"F$?YX0,"J@`-`)3```"0`,!'^0``0#D`"@`T
MTP``L-0``)"4ED?Y@`)`N9/__Y<"*%(Y0@`?,@(H$CF``D"YCO__E^$#`*KB
M3T"Y0!``$50,`!$B*%(Y`'Q]DT(``#(B*!(YG?__E^,#`*K"``"082("D>8C
M0/D```#P1,1'^0``%I'E3T"Y`@``\,<`0/E"X!61A`!`^6<(`*DC"`#Y9``!
MJ;\$`'$-"0!4(0"`TB`,`!'$>&'X(00`D638(/B_``%K;/__5*4,`!%U(@*1
M?]@E^.(#%"H!``"P!`"`TB'0&)&@!D#YS/[_E_0#`"K`!``T=2("D?93`9&@
M!D#Y2O__EP```/#A`Q:J`(`2D:,$`)0@!`"T<R("D6`&0/FR_O^7%?__EZ``
M`/``I$?YXB]`^0$`0/E"``'K`0"`TL$$`%3@`Q0J\U-!J?5;0JG]>\:HP`-?
MUO#^_Y?3``"08B("D4`$`/E``P"TM```\`[__Y>`ED?Y``!`N3___Y<?W"@Y
MJ/__%Z`&0/F__O^7]`,`*MC__Q>@#D#Y8```M"<)`)3=__\7X0,6J@```/``
MH!"1>@0`E*`.`/G@^O^T'PD`E-7__Q>%`(!2P/__%R``@%+!_O^7$/__EQ\@
M`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'0"`TAX`@-+E`P"JX0-`
M^>(C`)'F`P"1H```\`#,1_D#`(#2!`"`TDW__Y?0_O^7H```\`"<1_E```"T
MA/[_%\`#7]8?(`/5'R`#U<```)````*1P0``D"$``I$_``#KP```5*$``/`A
MK$?Y80``M/`#`:H``A_6P`-?UL```)````*1P0``D"$``I$A``#+(OQ_TT$,
M@8LA_$&3P0``M*(``/!"L$?Y8@``M/`#`JH``A_6P`-?UA\@`]7]>[ZI_0,`
MD?,+`/G3``"08`)".4`!`#6@``#P`*A'^8```+3```"0``1`^87^_Y?8__^7
M(`"`4F`"`CGS"T#Y_7O"J,`#7]8?(`/5'R`#U=S__Q<?(`/5'R`#U1\@`]7_
M@PK1H0``\.)C`)$%X`"1".`!D>0#`JK]>P"I_0,`D2&D1_DC`$#YXT\!^0,`
M@-*A`$"YA$``D:.$0/@A",!:@0`?^&'\8--G_&C3YQQXDB;<>-,A'`A3QAQP
MDN/@0ZHA``:J(0`#JH&`'_@?`07K`?[_5$4`")%!`$#Y0B``D4,$0/E$'$#Y
M8P`!RD$P0/DA``3*(0`#RB/\7]-A!`&J(7Q`DD$\`/E?``7K8?[_5`<H0*DD
M,X_2""1!J410J_+EFT&I(W2=TN+\6]/L_$+30A0'JHQY!ZHA`0C*(]NM\B$`
M"HHA``G*I0`$BR)`(HM!_4+3(7@*JD(`!8L+$$#Y+7Q`DJ4!",K&``2+0@`+
M"Z4`!XJE``C*(0`,RD[\6]-/_$+3I0`)B\X5`JJE``:+(0`"BN)Y`JJE``X+
MYK]"J2$`#<JN_%O3(0`(B\X5!:JP_$+3Q@`$B^\!!(LA``:+A@$"RB$`#@N,
M?4"2Q@`%BL8`#,HN_%O3Q@`-B\X5`:H->@6JQ@`/B\8`#@M%``W*[A]`^4)\
M0)*E``&*,/Q"TZ4``LK.`02+I0`,B\_\6],,>@&J[Q4&JJ$!#,JE``Z+[B-`
M^:4`#PNM?4"2(0`&BB$`#<K/_$+3YGD&JB$``HO"`02+KOQ;TR$``HNO_$+3
M@@$&RLX5!:HN``X+0@`%BN5Y!:J,?4"2X;]$J4(`#,I"``V+S?U;TZT5#JK0
M?$"2(0`$BT(``8O!``7*30`-"R$`#HHA`!#*QOU"T^(!!(O.>`ZJ(0`,BZS]
M6].F?$"2(0`"BXP5#:JB``[*I?U"TR\`#`NE>`VJ0@`-BN&W1:E"``;*0@`0
MB^S]6].,%0^J\/U"TR$`!(M"``&+P0$%RB$`#XK.?4"2(0`.RDP`#`L/>@^J
MH@$$BR$`!HN&_5O3(0`"BZ(`#\I"``R*I7Q`DD(`!<K&%`RJ0@`.BRT`!@OP
MNT:IAOU"T\9X#*JA_5O3+!0-JN$!!LHA``V*[WU`DB$`#\H0`@2+(0`%BT(`
M$(NP_4+33``,"PUZ#:K"`02+(0`"B\(`#<I"``R*QGQ`DD(`!LJ%_5O30@`/
MBZ44#*KPOT>I+@`%"X7]0M.E>`RJP?U;TRP4#JJA`07*(0`.BJU]0)(0`@2+
M(0`-RD(`$(O0_4+33``,"PYZ#JKB`02+(0`&BR$``HNB``[*0@`,BJ5\0))"
M``7*AOU;TT(`#8O&%`RJ\+=(J2\`!@N&_4+3QG@,JN']6],L%`^JP0$&RB$`
M#XK.?4"2$`($BR$`#LI"`!"+\/U"TTP`#`L/>@^JH@$$BR$`!8LA``*+P@`/
MRD(`#(K&?$"20@`&RH7]6]-"``Z+I10,JO"[2:DM``4+A?U"TZ5X#*JA_5O3
M+!0-JN$!!<HA``V*[WU`DA`"!(LA``_*0@`0B[#]0M-,``P+#7H-JL(!!(LA
M``:+(0`"BZ(`#<J&_5O3I7Q`DD(`#(K&%`RJ0@`%RBX`!@M"``^+AOU"T^&_
M2JG,>`RJQOU;T\84#JHA``2+Y`$$BT(``8NA`0S*(0`.BJU]0)(A``W*S_U"
MT](``@ON>0ZJ(0`%BT9`)HOO7T#Y(0`$BX0!#LI%_EO3A``&2N(!`XNE%!*J
MA``-BTW^0M.P``$+LGD2JH0``HOB8T#Y)4`EB\$!$LH&_EO3)0`%2L84$*I!
M``.+HD`LBPS^0M//``0+C7D0JD(``8OA9T#YAD`FBT0"#<KE_5O3A``&2J44
M#ZHF``.+@4`NB[$``@LA``:+[/U"TT5`)8OF:T#YCWD/JJ(!#\HD_EO310`%
M2H04$:K"``.+)OY"TY```0O1>!&JYF]`^21`)(OA`1'*K$`RBR0`!$H%_EO3
M@@$"BZ44$*K!``.+#/Y"TX9`+8NN``(+D'D0JL$``8OF<T#Y14`EBR("$,K$
M_5O30@`%2H04#JK&``.+0D`OB\S]0M.-``$+CGD.JD(`!HOF=T#Y)$`DBP$"
M#LJE_5O3(0`$2J44#:K&``.+(4`QBZ\``@LA``:+K/U"TT5`)8OF>T#YC7D-
MJL(!#<KD_5O3A!0/JD4`!4K"``.+YOU"TY$``0O/>`^JYG]`^21`)(NA`0_*
MK$`PBR0`!$HE_EO3@@$"BZ44$:K!``.++/Y"TX9`+HNP``(+C'D1JL$``8OF
M@T#Y14`EB^(!#,H$_EO30@`%2H04$*K&``.+0D`MBPW^0M..``$+0@`&BZ9Y
M$*KPAT#Y)$`DBX$!!LK%_5O3(0`$2J44#JH0`@.+(4`OBZT``@LA`!"+S_U"
MTT5`)8OPBT#Y[GD.JL(`#LJD_5O3A!0-JD4`!4H"`@.+L/U"TX\``0L->@VJ
M\(]`^21`)(O!`0W*K$`LBR0`!$KE_5O3I10/JH9`)HL!`@.+\/U"T\$``8N"
M`0*+!GH/JJP``@M%0"6+H@$&RD(`!4J$_5O30D`NBX[]0M.$%`RJS'D,JO`[
M4JF/``$+)$`DB\$`#,KE_5O3(0`$2J44#ZHA0"V+[?U"TQ`"`XNO>0^J0@`0
MB\X!`XNP``(+14`EB^V;0/F"`0_*!/Y;TT(`!4HA``Z+A!00JJ4!`XM"0":+
M#?Y"TXX``0M%``6+HGD0JO"?0/DD0"2+X0$"RL;]6],D``1*QA0.J@$"`XN$
M0"R+T/U"T\T`!0N$``&+`7H.JO"C0/FF0":+10`!RJS]6].E``9*C!4-JA`"
M`XNE0"^+K_U"TXX!!`OO>0VJI0`0B_"G0/F,0"R+)``/RL;]6].,``Q*QA0.
MJ@0"`XN"02*+S/U"T\T`!0M"``2+A'D.JJ9`)HOE`03*I0`&2J[]0M.P_5O3
MH4`ABQ`6#:K%>0VJ[#=5J4(`$`M._$+3A@$#BT/\6]-C%`*JC``%JB$`!HN,
M`0**(0`#"Z,`!`J,`0.JAIN7TF;CL?+">0*J@T$OBZP!!HLM_%O38P`,BZT5
M`:JL``*J[K-`^6,`#0N,`0&*30`%"HP!#:HO_$+3X7D!JLX!!HN$022+;?Q;
MTZT5`ZI,``&JA``.BXP!`XKNMT#YA``-"RT``@IO_$+3C`$-JLX!!HN-_%O3
MA4$EB^QY`ZJE``Z+HQ4$JBT`#*KNNT#YHP`#"Z4!!(J-`0$*C_Q"TZ4`#:K.
M`0:+I4`BBVW\6]/B>02JK14#JH0!`JJE``Z+A``#BNZ_0/FE``T+30`,"F_\
M0M.$``VJS@$&BX1`(8NM_%O3X7D#JJT5!:J$``Z+0P`!JH0`#0LN``(*[<-`
M^6,`!8JO_$+38P`.JN5Y!:JM`0:+8T`LBX[\6]/.%02J+``%JF,`#8N,`02*
M[<=`^6,`#@NN``$*C`$.JH[\0M."02*+K`$&BVW\6]/$>02JK14#JD(`#(M"
M``T+K``$JNW+0/F.``4*C`$#BF_\0M.,`0ZJXWD#JJT!!HN!02&+3OQ;TXP`
M`ZK.%0*J(0`-BR$`#@N,`0**;@`$"HP!#JI._$+3PGD"JH5!)8OMNUFI+_Q"
MTZP!!HLM_%O3K14!JJ4`#(ML``*JI0`-"XP!`8I-``,*C`$-JN%Y`:K.`0:+
MA$$DBZW\6]-,``&JK14%JH0`#HONUT#YA``-"XP!!8HM``(*C`$-JJ_\0M/.
M`0:+@T$CBXW\6]/L>06JK14$JB4`#*IC``Z+I0`$BN[;0/EC``T+C0$!"H_\
M0M.E``VJY'D$JLX!!HNB0"*+;?Q;TX4!!*JM%0.J0@`.B^[?0/E"``T+I0`#
MBHT`#`IO_$+3I0`-JLX!!HNA0"&+3?Q;T^5Y`ZJM%0*J@P`%JB$`#HM._$+3
M(0`-"V,``HK">0*JKP`$"NT[7*EC``^J;$`LBR/\6]-C%`&J+_Q"TZT!!HN,
M`0V+K0`"JH,!`PNL`0&*30`%"N%Y`:J,`0VJ;?Q;TX1!)(O,`0:+A``,BTP`
M`:HN``(*C`$#BHP!#JJM%0.JA4$EBX0`#0OO,UVI;?Q"TZUY`ZJ._%O3SA4$
MJN\!!HNC``^+)0`-JF,`#@NE``2*K@$!"J4`#JJ._$+3Q'D$JJ)`(HN%`0:+
M;/Q;TXP5`ZI"``6+;OQ"TZ4!!*I"``P+I0`#BL-Y`ZJ/``T*[#M>J:4`#ZJE
M0"&+0?Q;TR$4`JI/_$+3C`$&BZ4`#(N,``.JI0`!"XP!`HIA``0*XGD"JHP!
M`:I0``,*@4$MB\T!!HNL_%O3(0`-BXP5!:IM``*J[_M`^8X!`0NM`06*+$`L
MBZT!$*K0_4+3I$$DB^T!!HNO_$+3QOU;TX0`#8O&%`ZJ[7D%JM(`!`OO_T#Y
M00`-RB$`#$K%.IC214RY\B%`(XOL`06+0_Y;TPYZ#JHA``R+8Q02JH9`)HOL
M`T'Y<0`!"Z0!#LHC0".+A``&2H8!!8N"0"*+3/Y"TR3^6].2>1*J0@`&BX04
M$:KF!T'YD``""\$!$LI$0"2+(P`#2L$`!8ML0"V+)OY"TP/^6]/1>!&JC`$!
MBV,4$*KA"T'Y;P`,"T("$<J#02.+1``$2B(`!8N&0"Z+X?U;TP3^0M/&``*+
MD'@0JB$4#ZKB#T'Y+@`&"R0"$,KL_4+3A``#2D,`!8N$0#*+POU;TX]Y#ZJ$
M``.+0A0.JL%`(8OC$T'Y30`$"P8"#\K,_4+3P0`!2F8`!8LC0#&+H?U;TXYY
M#JIC``:+(10-JH)`(HOF%T'Y,@`#"^0!#LIA0"&+@@`"2L0`!8M,0#"+IOU"
MTT+^6]/->`VJA`$$BT(4$JKF&T'Y40`$"\,!#<I,_D+380`!2L,`!8LF0"^+
M(?Y;T\,``XN,>1*J(101JH)`(HOF'T'Y,``#"Z0!#,IA0"&+@@`"2L8`!8M$
M0"Z++OY"TP+^6].$``:+0A00JL9Y$:KN(T'Y3P`$"X,!!LJ"0"*+80`!2LX!
M!8LC0"V+#?Y"T^']6].P>1"J8P`.BR$4#ZKN)T'Y+0`#"\0`$,IA0"&+@@`"
M2L0!!8M,0"R+[OU"TZ+]6]//>0^JA`$$BT(4#:KL*T'Y3@`$"P,"#\J"0"*+
M80`!2H,!!8LF0":+K/U"T\']6]/#``.+(10.JH9Y#:KL+T'Y+0`#"^0!!LIA
M0"&+@@`"2HP!!8M$0#"+T/U"TZ+]6],.>@ZJA``,BT(4#:KL,T'Y40`$"\,`
M#LJ"0"*+80`!2HP!!8LC0"^+K_U"TR'^6]/M>0VJ8P`,BR$4$:KL-T'Y,``#
M"\0!#<HO_D+3@@`"2H0!!8M,0":+`OY;TX8!!(M"%!"J['D1JF%`(8OD.T'Y
M3P`&"Z,!#,K"0"*+80`!2H,`!8LD0"Z+#OY"T^']6].$``.+(10/JL-Y$*KP
M/T'Y+@`$"X8!`\J!0"&+P@`"2A`"!8M&0"V+[?U"T\+]6].O>0^J0A0.JL8`
M$(OM0T'Y4``&"V0`#\K&0"*+A``!2J$!!8N,0"R+S?U"TP3^6].,`0&+A!00
MJJYY#JKA1T'Y@@`,"^T!#LKG0"^+K0$&2B8`!8NC02.+0?Q;TR$4`JIC``:+
M8P`!"P'^0M/M2T'Y(7@0JH9!)(O0`0'*9/Q;TZP``-`/`@9*A!0#JJ8!!8M%
M_$+3Q@`'BZ)X`JJ'I4?YA``/BR$`"0O%`0L+8P`*"X0`!@M"``@+!`P`J0($
M`:D%$`#YX$]!^>$`0/D```'K`0"`TH$``%3]>T"I_X,*D<`#7]:@^O^7_7N\
MJ?T#`)'S4P&I@`8`M/=C`ZGW`P"JH```T`#(1_D8`$#Y&`8`M/5;`JGV`P&J
M%0"`4N`"0#D?]`!Q!!A`>J$"`%03`T#YLP$`M+5^0)/T`QBJX@,5JN$#%ZK@
M`Q.J3_K_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.IX`,3JO-3
M0:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^;__Q>4`AC+M08`
MD7,"%8N4_D.3U`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+I__\7
M$P"`TO=C0ZGF__\7_7NUJ:(``-#]`P"10J1'^?,+`/GAHP"1\P,`JD,`0/GC
M5P#Y`P"`TFGZ_Y<@`@`UX3M`N0(`E%(A#!02/Q!`<2000GJ@`0!4H0``T"&D
M1_GC5T#Y(@!`^6,``NL"`(#2@0$`5/,+0/G]>\NHP`-?U@``@%+U__\7X`,3
MJD$`@%(3^O^7'P``<>`7GQKO__\7/_K_EQ\@`]4?(`/5_7NSJ:$``-#]`P"1
M(:1'^2(`0/GB9P#Y`@"`TL```+3S4P&I\P,`J@$`0#EA`0`U\U-!J:```-``
MI$?YXF=`^0$`0/E"``'K`0"`TD$)`%3]>\VHP`-?UD;Z_Y?T`P"J@/[_M/=C
M`ZD7``#0^",!D??B#I'U6P*IX`,4JM'Y_Y>`!0"T`4Q`.15,`)$_N`!Q@0``
M5*$&0#D!__\T'R`#U0!,0#D?N`!Q0`4`5.`#$ZIH^O^7]@,`JN`#%:IE^O^7
MP`(`"P`(`!$`?$"3$?K_E^4#%:KD`Q.JXP,7J@(`@)+U`P"J(0"`4E[Z_Y?A
M`QBJX`,5JLOY_Y<?!``QH```5.!;0+D`#!02'Q!`<>`"`%3@`Q6J;_G_E^`#
M%:HQ^O^7X`,4JJ?Y_Y?@^O^U'R`#U>`#%*JS^?^7X`,3JLGY_Y?S4T&I]5M"
MJ?=C0ZFZ__\7H`9`.1^X`'&A^O]4H`I`.<#X_S32__\7X`,5JJ7__Y?J__\7
M\U,!J?5;`JGW8P.IW/G_E_U[OJG]`P"1\PL`^;,``-!SED?Y8`)`N>WY_Y=@
M`D"YZ_G_EZ(``-`C``#0`0``T&-`#Y%"N$?Y(0`/D0SZ_Y=@`D"YXOG_EZ(`
M`-`$``#0\PM`^83`')']>\*HXP,$JD*@1_D!``#0!0"`4B&`#Y&?^?\7'R`#
MU1\@`]4,"(+2_V,LRZ,``-#B_X'2_7L`J?T#`)%CI$?Y\U,!J?0#`*KU6P*I
M]>,`D?8#`:I@`$#YX!\(^0``@-+A`Q6J````T`#@#Y$Z^?^7'P``<8T"`%0#
M!`!1H<IC.*$$`#4#`@`T<WQ`D^`#%:KB`Q.JX06`4M?Y_Y=``0"TH```T`"4
M1_D``$"YLOG_E^,#$ZKB`Q6JX0,4JI+Y_Y<(```4H```T`"41_D``$"YJ?G_
ME^(#%JKA`Q2J-OG_EZ```-``I$?YXA](^0$`0/E"``'K`0"`TB$!`%0,"(+2
M_7M`J?-30:GU6T*I_V,LB\`#7];C`P`JW/__%W[Y_Y<?(`/5_7NZJ:(``-#]
M`P"1\U,!J?,#`*KT`P&J]5L"J?=C`ZE"I$?Y(`!`.4$`0/GA+P#Y`0"`TA_T
M`'&4%I2:X`,4JL3Y_Y?V`P"JX5,!D>`#$ZK)_O^70`@`M/4#`*J]^?^7WP(`
MZ^D&`%3X5X"YMP``T!CS?=-@`D`Y'_0`<0080'I`#`!4Y`,3JH,<0#A_]`!Q
M9!A`>J'__U2$`!/+A'Q`D_?*1_G`"@"1```$B_8"0/E8^?^7P&HX^,`"`+3A
M`D#YX`,3JB-H>/@!%$`X80``.3_T`'$D&$!ZX```5!\@`]4"%$`X8AP`.%_T
M`'%$&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S6@``#0`*1'
M^>(O0/D!`$#Y0@`!ZP$`@-*A!P!4\U-!J?5;0JGW8T.I_7O&J,`#7]8!`(#2
M'R`#U8)J83BB:B$X(00`D:+__S7N__\7MP``T/EK!*G@RD?Y&@!`^4`#0/D`
M!0"TX`,:JA4`@%(?(`/5`8Q`^.(#%2JU!@`1H?__M4`,`!$`?'V3H0``\"*(
M0+DB`@`U(@"`4B*(`+D9^?^7^0,`JH`#`+2X?GV3X0,:JN(#&*I3^?^7X,I'
M^1D``/F@!@`1]5<`N3_;(/CY:T2II?__%^$#`*K@`QJJK?C_E_D#`*KARD?Y
M(```^4`!`+2X?GV3\___%P0`@-*E__\7``*`TA4`@%+@__\7^6L$J?3X_Y?Y
M:T2INO__%Q\@`]7]>[^IH```T/T#`)$`E$?Y``!`N0/Y_Y?]>\&HH@``T",`
M`-`!``#00KA'^6-`#Y$A``^1(_G_%Q\@`]4?(`/5#`J$TO]C+,N@``#0`0B"
MTOU[`*G]`P"1`*1'^?-3`:GS8R&+]1,`^?7C`)$4`(#2`0!`^>$G$/D!`(#2
M9?C_E^0#`"H%``#0`P``T*4@$)%C0!"1(@""TB$`@%+@`Q.J)/G_E^`#$ZKA
M`Q6J`@""TE3X_Y>``?@W\P,`J@`$`!$`?$"3Q_C_E_0#`*K```"T<WY`D^$#
M%:KB`Q.J7?C_EY]J,SB@``#0`*1'^>(G4/D!`$#Y0@`!ZP$`@-(!`0!4X`,4
MJ@P*A-+]>T"I\U-!J?430/G_8RR+P`-?UJGX_Y?(__\7#!R"TO]C+,NB``#0
M_7L`J?T#`)%"I$?Y\U,!J?,#`:KU6P*IX5,!D?4#`*I#`$#YXV\(^0,`@-(`
M``#0`*`0D?C]_Y?T`P"JX06`4N`#%:J_^/^78`(`M.$#%:H```#0`.`0D1+_
M_Y?@`Q6JH0``T"&D1_GC;TCY(@!`^6,``NL"`(#280P`5`P<@M+]>T"I\U-!
MJ?5;0JG_8RR+P`-?UN`#%:KW8P.IU?C_E_@#`*K@`Q.JGOC_EQ<``-#A(A&1
M__?_E_,#`*H`"@"T]F,#D?EK!*D:``#0&0``T%J#$)$Y0Q&18`)`.2`&`#2T
M``"TX0,3JN`#%*I]^/^7@`0`-.`#$ZJ^^/^7`@0`46'"(HMCRF(X?[P`<0$!
M`%3@`P(J0@0`43\``#EAPB*+8\IB.'^\`'%`__]4`0<`$2````L?_#]Q[`(`
M5.0#$ZKF`Q6JY0,9J@,``-!C8!&1`@""TB$`@%+@`Q:JJ?C_E^%C`9'@`Q:J
M%OC_EZ```#7@:T"Y``P4$A\@0'%@`@!4X2(1D0``@-+*]_^7\P,`JD#Z_[7W
M8T.I^6M$J:S__Q>4``"T@`)`.1^X`'&```!4\P,:JB``@%+=__\7@`9`.0#^
M_S3[__\7X`,6JB$`@%(`^/^78/W_->$#%JH```#0`.`0D:_^_Y?@`Q:J3?C_
ME_=C0ZGY:T2IFO__%_=C0ZF3__\7]V,#J?EK!*DA^/^7`@!`.>$#`*KB```T
M'R`#U2$$`)%?O`!Q`!"!FB(`0#F"__\UP`-?UA\@`]4?(`/58`@`M/U[OJG]
M`P"1\PL`^?,#`*H!`$`YH08`-&7X_Y<"!`#18@("BW\"`NNC``!4-```%$($
M`-%_`@+KX`$`5$``0#D?O`!Q8/__5'\"`NN"!0!40@0`T7\"`NO@``!40`!`
M.1^\`''@`0!40@0`T7\"`NMA__]48`)`.1^\`'%@`P!4\PM`^0```-#]>\*H
M`$`1D1/X_Q=``$`Y'[P`<8$``%1"!`#1?P("ZV/__U1"`!/+``"`TD$(`)$_
M!$#Q"`$`5*```/`$H`*10@0`D>$#$ZK@`P2J`P""TOGW_Y?S"T#Y_7O"J,`#
M7];S"T#Y````T/U[PJ@`@!"1^??_%W\"`NL!_?]4W/__%P```-``@!"1\_?_
M%Q\@`]4?(`/5_7NWJ2```-"B``#0`$`/D?T#`)$`0`"10J1'^?5;`JFU``#0
MX8,!D?-3`:D4``#0]V,#J92"$9'S<P&1^2,`^;7*1_E#`$#YXT<`^0,`@-(`
M!$"M`D!`>2)``'D@!`"MX0,3JN`#%*H3_?^7X`$`M*("0/GC7X"Y0`P#BP$$
M0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4J@7]_Y=@_O^UM0``
MT!0``-"4PA&1M<I'^>$#$ZK@`Q2J_?S_E^`!`+2B`D#YXU^`N4`,`XL!!$#Y
M07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%*KO_/^78/[_M;4``-`4
M``#0E.(1D;7*1_GA`Q.JX`,4JN?\_Y?@`0"TH@)`^>-?@+E`#`.+`01`^4%X
M(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q2JV?S_EV#^_[6U``#0%```
MT)0B$I&URD?YX0,3JN`#%*K1_/^7X`$`M*("0/GC7X"Y0`P#BP$$0/E!>"/X
MX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JL/\_Y=@_O^UM0``L!0``+"6
M0A*1M<I'^>$#$ZK@`Q:JN_S_E^`!`+2B`D#YXU^`N4`,`XL!!$#Y07@C^.'^
M_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%JJM_/^78/[_M;8``+`5``"PM8(2
MD=;*1_GA`Q.JX`,5JJ7\_Y?@`0"TP@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T
M`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q6JE_S_EV#^_[6V``"P%0``L+>B$)'6
MRD?YX0,3JN`#%ZJ/_/^7X`$`M,("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(
M0/D!!`#Y`"``D:'__[7A`Q.JX`,7JH'\_Y=@_O^UMP``L!8``+#8PA*1]\I'
M^>$#$ZK@`QBJ>?S_E^`!`+3B`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y
M`00`^0`@`)&A__^UX0,3JN`#&*IK_/^78/[_M;@``+`7``"P^0(3D1C+1_GA
M`Q.JX`,9JF/\_Y?@`0"T`@-`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$
M`/D`(`"1H?__M>$#$ZK@`QFJ5?S_EV#^_[6Y``"P&```L!A#$Y$YRT?YX0,3
MJN`#&*I-_/^7X`$`M"(#0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y
M`"``D:'__[7A`Q.JX`,8JC_\_Y=@_O^UN0``L!@``+`8XQ"1.<M'^>$#$ZK@
M`QBJ-_S_E^`!`+0B`T#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#&*HI_/^78/[_M>$#$ZH```"P`(`3D23\_Y?A`P"J8```
MM.`"$Y%#_?^7X0,3J@```+``X!.1'/S_E^$#`*J```"T````L`!`%)$Z_?^7
MX0,3J@```+``@!21$_S_E^$#`*J``@"TH*(0D3+]_Y>`0A*1`0``L"%@%9$N
M_?^7H```L`"D1_GB1T#Y`0!`^4(``>L!`(#2X0,`5/-30:GU6T*I]V-#J?DC
M0/G]>\FHP`-?UN$#$ZH```"P`,`4D?K[_Y?A`P"J@```M,#"$I$9_?^7Y___
M%P$JB-+B$T?X0>JK\F&(R?*A*.CR7P`!ZP'\_U3ADT=XP*F'4C\``&N!^_]4
MP,(2D>'O`9$*_?^7V/__%X3V_Y?]>[VIH0``L/T#`)$AI$?Y\PL`^;,``-`B
M`$#YXA<`^0(`@-)@$D"Y'P0`,6`!`%2A``"P(:1'^>,70/DB`$#Y8P`"ZP(`
M@-(A`@!4\PM`^?U[PZC``U_6X9,`D0```+``P!*1R_O_E^$#`*H``(!2H0``
MM"``0#D?P`!Q!!A`>N`'GQI@$@"YZO__%V#V_Y?]>[^I_0,`D47V_Y?T]?^7
M0```M```0/G]>\&HP`-?UOU[O*FB``"P_0,`D4*D1_GS4P&IX=,`D?5;`JD5
M``"PMH(5D4,`0/GC'P#Y`P"`TO0#`*K@`Q:JJOO_EX```+0!`$`Y\P,`JL$!
M`#6@``"P`*1'^>(?0/D!`$#Y0@`!ZP$`@-(A!@!4X0,4JJ""%9'S4T&I]5M"
MJ?U[Q*B\_/\7X0,4JO+U_Y>``0"TH```L`"D1_GB'T#Y`0!`^4(``>L!`(#2
M(00`5/-30:GU6T*I_7O$J,`#7];@`Q2J@/;_E_4#`*K@`Q.J??;_EZ`"`(L`
M"`"1*O;_E^8#$ZH"`("2(0"`4N0#%*KS`P"J!0``L`,``+"E(!&18V`1D73V
M_Y>B``"P0J1'^>`?0/E!`$#Y```!ZP$`@-*!``!4X0,3JN`#%JK3__\7#?;_
ME_U[OZD`$(#2_0,`D1'V_Y<?&`#Y)F"$TB5QE=+$GYO2PXZ*T@(^G-*FZ*SR
MI?F]\D07L_)#!J+R0GJX\@84`*D$#`&I`GP"J1]X`+G]>\&HP`-?UOU[O*FA
M``"P_0,`D2&D1_GS4P&I]`,`JO5;`JDB`$#YXA\`^0(`@-+9_?^7`0!`.?,#
M`*KA```T'R`#U0`$`)$_O`!Q<Q*`F@$`0#F!__\UM@``T)\"`/'U!Y\:P!)`
MN1\$`#&`!`!4'P``<>`'GQJU`@`*E0$`-:```+``I$?YXA]`^0$`0/E"``'K
M`0"`T@$%`%3S4T&I]5M"J?U[Q*C``U_6@`)`.8#^_S0!``"PX`,3JB'`%9&"
M`(#2D/7_E\#]_S6@``"P`*1'^>(?0/D!`$#Y0@`!ZP$`@-*A`@!4X`,4JO-3
M0:GU6T*I_7O$J'_[_Q<```"PX=,`D0#`$I$8^_^7H```M```0#D?P`!Q!!A`
M>F$``%3?$@"YU___%R``@%+`$@"YE?K_--[__Q>K]?^7'R`#U1\@`]7]>[RI
M0GQ`D_T#`)'S4P&I%.``D?,#`:KU6P*I]0,`JO8#`JKW8P.I!8Q"J0!X0+FD
M#`(+OP`$ZV.4@YIB=$*+I(H"J:`#`#7?_@!QK04`5-8"`5'8?@93%P<`$?=J
M>M-W`A>+'R`#U6`&0*W@`Q6J@`8`K6`&0:US`@&1@`8!K<CV_Y=_`A?K`?__
M5-8:&$OA`Q>JX`,4JL)^0),E]?^7MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6
M%PB`4O<"`$O_`A9K@,(@B_?2EAKX?D"3X@,8JA?U_Y>@>D"YX`(`"Z!Z`+D?
M``%QX?W_5-8"%TMS`AB+X`,5JJKV_Y?3__\7]P,3JN/__Q<?(`/5'R`#U?U[
MO*GB#X`2_0,`D?-3`:GT`P"J\P,!JO5;`JDUX`"1]QL`^2`40/DV*$"Y-S!`
MN0`@`U/6"L!:`00`$?<*P%JBRB`XH,(ABS_@`'&-"0!4`@B`4D(``4L!`(!2
M0GQ`DZSU_Y?@`Q.JBO;_EW\V`/D`!`!/H`(`K:`*@#W@`Q.J=UH.*8/V_Y=A
M`D#YX`,3JB'\6-.!`@`Y80)`^2'\4-.!!@`Y80)`^2'\2-.!"@`Y80)`^8$.
M`#EA!D#Y(?Q8TX$2`#EA!D#Y(?Q0TX$6`#EA!D#Y(?Q(TX$:`#EA!D#Y@1X`
M.6$*0/DA_%C3@2(`.6$*0/DA_%#3@28`.6$*0/DA_$C3@2H`.6$*0/F!+@`Y
M80Y`^2'\6-.!,@`Y80Y`^2'\4-.!-@`Y80Y`^2'\2-.!.@`Y80Y`^8$^`#EA
M$D#Y(?Q8TX%"`#EA$D#Y(?Q0TX%&`#EA$D#Y(?Q(TX%*`#EA$D#Y@4X`.?-3
M0:GU6T*I]QM`^?U[Q*A"]?\7`@>`4D(``4L!`(!20GQ`DV'U_Y>[__\7##*0
MTO]C+,NA``"P_7L!J?U#`)$AI$?Y]V,$J;<``-#B0@"1\U,"J4.``)'U6P.I
M]@,`JO0S`I'Y:P6I^0,#D1@``+!$E$"I1AQ%J6`$0*UB",`]`P*0TN-C(XL@
M`$#Y8+P`^0``@-+A`Q2J0PQ`^0"C$)%",$#Y(`<`K>8?":GB4P#YY)<*J>-?
M`/GB.X`]//K_EX```+0!`$`Y\P,`J@$A`#7[<P:IO?3_EVST_Y=`'`"T&@!`
M^1H<`+3@`QJJ)_7_EP#X?],`!`"1U/3_ET0#0#GU`P"JI`$`-!L``+#S`Q6J
M>T,6D1\@`]7@`Q.JXP,;J@(`@)(A`(!2'/7_EW,*`)%$'T`X)/__-0$``+`Y
M(P"1($`4D0,``!0@AT#XX`D`M.$#%*H6^O^7\P,`JF#__[0!`$`Y(?__-$WZ
M_Y?@_O\TX`,3JM'T_Y?S`P"J8`@`M.`#$ZH!]?^7^0,`JN`#%:K^]/^7.P,`
M"WL3$!$:``"P>W]`D^`#&ZJH]/^7YP,5JN0#$ZI%0Q&1!@``L`,``+#&P!61
M8V`6D0(`@)+Y`P"J(0"`4O'T_Y?@`QFJ`3B`4L;T_Y<?!``QH0``5'OT_Y<%
M`$"YOT0`<4$6`%3\PP.1X`,9JN$#'*J8]/^7\P,`*@`&`#2@``"P`@``L,,"
M0/GD`QFJ`+1'^4*@%Y$A`(!2%0"`T@``0/ET]/^7H```L`$"D-+B8R&+`*1'
M^4.\0/D!`$#Y8P`!ZP$`@-(A*@!4X`,5J@PRD-+]>T&I\U-"J?5;0ZGW8T2I
M^6M%J?MS1JG_8RR+P`-?UOJC`I$9`(!24]MY^+,!`+1@`D`Y8`$`-#D'`!'@
M`Q.J_?G_ER#__S3@`Q.J@?3_E_,#`*H@]O^U4]MY^+/^_[43`(#2K?__%^`#
M0;D`#!02'Q!`<<'Y_U3U"T&Y.?3_E[\"`&M!^?]4X`-!N0`@`!(?``=QP?C_
M5.`#&ZI1]/^7`0``L/4#`*H@`!F1X0,4JJ7Y_Y?A`P"JP!``M,`"0/F9^_^7
M^P,`JD`0`+3@`QNJE/3_E^(#`*H?#`!Q+0(`5`!\0),!``"P`!``T2$@&9%@
M`P"+XC\`^4;T_Y<@`0`UXC]`^5\0`''`&P!40!0`46#+8#@?O`!Q0!L`5!\@
M`]7@$D"Y'P0`,8`-`%06``"P@`X`-,#"$I$!``"P(6`5D:3Z_Y=:0Q&1%```
ML)3"')$6``"PK_/_E];B&9'F`P`JYP,4JN4#&JKD`QFJX`,5J@,``+`"`("2
M8Z`9D2$`@%)L]/^7$0``%/KS_Y<``$"Y'T0`<4$"`%2>\_^7]`,`^7,&`!'F
M`P`JYP,3*N4#&JKD`QFJXP,6JN`#%:H"`("2(0"`4EOT_Y?@`Q6J`3B`4C#T
M_Y<?!``Q@/W_5.`#&:HT]/^7X0,5J@"C$)%Y^O^7X`,5JIS]_Y=W__\7\T,"
MD14`@%(?(`/58-IU^(`!`+3A`Q2JM08`$4OY_Y=@__^T`0!`.2'__S0*]/^7
M^@,`JH#B_[5@VG7XP/[_M:`!@-+H\_^7&@``L/4#`*I:(Q:19`J`4A/__Q>@
M``"PY`,9JL,"0/D"``"P`+1'^4*@%I$A`(!2%0"`T@``0/G)\_^75?__%WC]
M_Y>@``"P`@*0TN)C(HL`I$?Y0[Q`^0$`0/EC``'K`0"`TJ$4`%3@`Q.J##*0
MTOU[0:GS4T*I]5M#J?=C1*GY:T6I_V,LB^'S_Q?;`D#Y?O__%Q8``+#A`Q2J
MP,(2D1CY_Y>@``"T``!`.1_``'$$&$!ZX0L`5/\2`+G@`QNJ`0"`4A8``+`!
M]/^7]`,`*@#Q_S1"`(!2(0*`DO8C!I$K\_^7X0,6JN`#%"K"`(#2E_/_E^`C
M1CF````UX"=&.1\,`7&`"P!4`@"`4@$`@-+@`Q0J'O/_EP`0@-*@\_^7\P,`
MJB1@A-(C<972PI^;TL&.BM(`/IS2I.BL\J/YO?)"%[/R00:B\D!ZN/)D#@"I
M8@8!J6!^`JE_&@#Y?WH`N04``!3B`P`JX0,6JN`#$ZK;_?^7X0,6JN`#%"H"
M`)#2<_/_EQ\``''L_O]4X`,4*O3#!9'&\_^7]@,4JN`#%*H;``"P]`,<JI>C
M`)%[0Q:1X0,3J@[^_Y<?(`/5Q!9`..`#%*KC`QNJE`H`D0(`@)(A`(!2QO/_
ME_\"%.L!__]4Y@,<JD5#$9'D`QFJ!P``D`,``)#GP!R18V`9D0(`@)(A`(!2
MX`,5JO]C!#FX\_^7X`,9JI;S_Y?A`Q6J`*,0D=OY_Y?@`Q6J_OS_E]G^_Q<@
M`(!2X!(`N2[__Q?6!D#Y]N3_M.`#%JJE\_^7'PP`\6GD_U0`$`#1`0``D,`"
M`(LA0!F16O/_EQ\``'%[$Y::&___%^`K1CD?!`%Q8?3_5.`O1CD?#`%Q`?3_
M5.`S1CD?(`%QH?/_5.`W1CD?%`%Q0?/_5.`#%"I"`(!2(0>`DK?R_Y?A`Q:J
MX`,4*B(%@-(C\_^7Y@,6JD5#$9'D`QFJX`,5J@<``)`#``"0Y\`<D6-@&9$"
M`("2(0"`4H#S_Y<J__\7(O/_E_MS!JD@\_^7_7N[J:$``)#]`P"1\U,!J;,`
M`)#U6P*I]A,!D7661_GW&P#Y(:1'^:`"0+DB`$#YXB<`^0(`@-(I\_^7]`,`
MJJ`"0+DF\_^7X@,`JH/"0CD```"0X0,6J@!`$I%#Q`(Y:/C_EX```+0!`$`Y
M/\0`<:`+`%0V^_^7=99'^:`"0+D7\_^7`0``D&,`@%(A0!J1(@"`4IKR_Y?T
M`P"J@`$`M*`"0+D.\_^7@0I`^0(``)!"8!J1(0!`^9GR_Y>`"D#Y``!`^0`,
M0+E`"[`W=Y9'^;4``+#@`D"Y`?/_EP$``)!C`(!2(8`:D2(`@%*$\O^7]`,`
MJL`!`+3A`Q:J````D`#@$)$_^/^7X0)`N?<#`*K@`P$J]P<`M/'R_Y>!"D#Y
MX@,7JB$`0/E]\O^7<Y9'^;<B`I%@`D"YZ?+_E_0#`*I@`D"YYO+_ER(`@%(!
M``"0(:`:D4;R_Y<"``"0X0,`JD(`&Y'@`Q2J;?+_EV`"0+G;\O^7X@,`JN$#
M%JH```"0`*`0D5_$`CD>^/^7X`X`^?,#`*K@`@"T`3B`4N`#$ZKK\O^7`00`
M$3\$`'$$B%%ZX00`5*```)``I$?YXB=`^0$`0/E"``'K`0"`TN$#`%3S4T&I
M]5M"J?<;0/G]>\6HP`-?U@`$0#F`]/\THO__%^`*0/FC_?^7X`X`^?,#`*K`
M_/^U````D``@&Y'$\O^7L_+_EZ`B`I&""D#Y`0A`^4``0/DA`$#YV?C_E\#_
M_Q>@`D"YJO+_EX$*0/DA`$#YF_+_EZ+__Q>-\O^7M2("D>,#`"KB`Q.J````
MD`#`&Y&A"D#Y(0!`^:WR_Y>C``"P8P1`^7+R_Q<?(`/5_7N_J?T#`)']>\&H
MP`-?U@$``@``````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+W-E;&8O97AE
M``!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0````
M``````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``
M4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`
M````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/
M0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?
M5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M`````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%4
M2`!P87(M`````"UE````````+2T```````!365-414T``"4P,G@`````)7,E
M<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L````
M`"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,`````````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U-````%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O
M9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H
M<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM>2`D;6%G
M:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C($Y/5$4Z
M("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P
M.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S
M("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A
M7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L
M("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU
M;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP
M(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?
M1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D
M9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM
M>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L
M("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A
M;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\
M("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E
M;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*````55-%4@````!54T523D%-10``````````
M5$U01$E2``!414U01$E2`%1%35``````5$U0```````O=&UP`````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M```!&P,[^````!X````\B___A`4``'R-__\0`0``S(W__R0!``#\C?__.`$`
M`#R.__],`0``C([__W`!``"<CO__A`$``""?__^H`0``$*#__Q`"``"LH/__
M.`(``#"B__^8`@``K*+__[P"``"LH___]`(``-RE__](`P``'*;__V@#``#\
MIO__G`,```"G__^P`P``'*G__QP$``!,J?__,`0``&RJ__]L!```D*___Z@$
M```@L/__S`0``$"P___L!```;+'__R@%``#`L?__2`4``/RR__^T!0``#+3_
M_^P%``"@M?__(`8``""]__^X!@``C+___^P&```0``````````%Z4@`$>!X!
M&PP?`!`````8````9(S__S0`````00<>$````"P```"@C/__,``````````0
M````0````+R,__\\`````````"````!4````Z(S__T@`````00X@G02>`T*3
M`D[>W=,.`````!````!X````%(W__P0`````````(````(P````0C?__A!``
M``!!#J`%1IU4GE,#&`0*W=X.`$$+9````+````!PG?__\`````!!#D"=")X'
M0I,&E`5"F`&7`D:6`Y4$5=;50=C70][=T]0.`$$.0),&E`65!)8#EP*8`9T(
MG@=/UM5!V-=!WMW3U`X`00Y`DP:4!9T(G@="EP*8`4+8UP`D````&`$``/B=
M__^4`````$$.L`&=%IX51),45@K>W=,.`$$+````7````$`!``!LGO__A`$`
M``!!#M`!G1J>&4B4%Y,81-332-[=#@!!#M`!DQB4%YT:GAE$F!.7%$26%946
M<PK4TT'6U4'8UT$+2=/4U=;7V$&4%Y,80985E19!F!.7%```(````*`!``"0
MG___=`````!!#B"=!)X#0I,"5-[=TPX`````-````,0!``#HG____`````!"
M#L`@0YV(!)Z'!$.3A@24A01"E80$EH,$<0K=WM76T]0.`$$+``!0````_`$`
M`+"@__\L`@```$$.8)T,G@M#DPJ4"4R5")8'EP:8!7\*WMW7V-76T]0.`$$+
M29H#F01?"MK900M)V=I"F02:`T/9VD&:`YD$0MK9```<````4`(``(RB__\X
M`````$$.$)T"G@%&WMT.`````#````!P`@``K*+__^``````0@[00$.=B@B>
MB0A#DX@(E(<(0I6&"&P*W=[5T]0.`$$+```0````I`(``%BC__\$````````
M`&@```"X`@``2*/__QP"````0@[@(4*=G`2>FP1#DYH$E)D$0Y68!):7!%T*
MW=[5UM/4#@!!"T*8E027E@1+FI,$F90$=`K8UT':V4$+5=C70=K909>6!)B5
M!$'8UT*8E027E@1!FI,$F90$`!`````D`P``^*3__R@`````````.````#@#
M```4I?__&`$```!"#B"=!)X#0I,"8`K>W=,.`$(+5`K>W=,.`$$+0PK>W=,.
M`$(+0PX`T]W>.````'0#``#XI?__)`4```!!#I`!G1*>$4>5#I8-0Y,0E`]%
MEPR8"YD*`Q\!"M[=V=?8U=;3U`X`00L`(````+`#``#@JO__D`````!!#C"=
M!IX%1),$4`K>W=,.`$$+'````-0#``!,J___(`````!!#A"=`IX!1M[=#@``
M```X````]`,``$RK__\L`0```$$.0)T(G@=&DP:4!94$E@-8"M[=U=;3U`X`
M00M-"M[=U=;3U`X`00L````<````,`0``#RL__]4`````$$.$)T"G@%3WMT.
M`````#@```!0!```<*S__S0!````00Y`G0B>!T23!I0%0I4$E@-A"M[=U=;3
MU`X`00M3"M[=U=;3U`X`00L``"P```",!```L(7__R0"````00Y@G0R>"T63
M"I0)E0B6!P)A"M[=U=;3U`X`00L``#0```"\!```0*W__P@!````00Y`G0B>
M!T.3!I0%0Y4$E@-#EP*8`6,*WMW7V-76T]0.`$$+````,````/0$```8KO__
ME`$```!!#D"=")X'0Y,&E`5#E026`T*7`@)5"M[=U]76T]0.`$$+`)0````H
M!0``>*___X`'````0@Z0@P)"G;`@GJ\@0Y>J()BI($63KB"4K2"5K""6JR!#
MF:@@FJ<@6YRE()NF(`)K"MS;0=W>V=K7V-76T]0.`$$+`IG;W%+=WMG:U]C5
MUM/4#@!!#I"#`I.N()2M()6L():K()>J()BI()FH()JG()NF()RE()VP()ZO
M(`*;V]Q!G*4@FZ8@,````,`%``!@MO__;`(```!!#E"="IX)0Y,(E`="E0:6
M!4.7!`)O"M[=U]76T]0.`$$+`!````#T!0``F+C__PP``````````````)`B
M````````0"(````````!``````````0#`````````0`````````4`P``````
M``$`````````'@,````````,`````````#@;````````#0````````"<4P``
M`````!D`````````")L!```````;``````````@`````````&@`````````0
MFP$``````!P`````````"`````````#U_O]O`````)@"````````!0``````
M```H#0````````8`````````@`,````````*`````````)\$````````"P``
M```````8`````````!4````````````````````#`````````"B=`0``````
M`@````````"@!0```````!0`````````!P`````````7`````````)@5````
M````!P````````#X$@````````@`````````H`(````````)`````````!@`
M````````'@`````````(`````````/O__V\``````0``"`````#^__]O````
M`)@2````````____;P`````"`````````/#__V\`````R!$```````#Y__]O
M`````!``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!0&P```````%`;````````4!L`
M``````!0&P```````%`;````````4!L```````!0&P```````%`;````````
M4!L```````!0&P```````%`;````````4!L```````!0&P```````%`;````
M````4!L```````!0&P```````%`;````````4!L```````!0&P```````%`;
M````````4!L```````!0&P```````%`;````````4!L```````!0&P``````
M`%`;````````4!L```````!0&P```````%`;````````4!L```````!0&P``
M`````%`;````````4!L```````!0&P```````%`;````````4!L```````!0
M&P```````%`;````````4!L```````!0&P```````%`;````````4!L`````
M``!0&P```````%`;````````4!L```````!0&P```````%`;````````4!L`
M``````!0&P```````%`;````````4!L```````!0&P```````%`;````````
M4!L```````!0&P```````%`;````````4!L```````!0&P```````%`;````
M````4!L````````8FP$``````````````````````````````````````"11
M````````````````````````````````````````````````````````````
M`````````````````````````````````'B@`0````````````````!`'P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"*`!``````#_____`````,B3````````(%0`
M`````````````````!!5````````J),```````"PDP```````+B3````````
MP),``````````````````)"3````````F),``````````````````#A7````
M````1T-#.B`H56)U;G1U(#$Q+C(N,"TQ-G5B=6YT=3$I(#$Q+C(N,```+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT
M86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R
M<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````#@"````
M````.`(````````;`````````````````````0```````````````````!,`
M```'`````@````````!4`@```````%0"````````)```````````````````
M``0````````````````````F````!P````(`````````>`(```````!X`@``
M`````"`````````````````````$````````````````````-````/;__V\"
M`````````)@"````````F`(```````#H``````````4`````````"```````
M`````````````#X````+`````@````````"``P```````(`#````````J`D`
M```````&`````P````@`````````&`````````!&`````P````(`````````
M*`T````````H#0```````)\$```````````````````!````````````````
M````3@```/___V\"`````````,@1````````R!$```````#.``````````4`
M`````````@`````````"`````````%L```#^__]O`@````````"8$@``````
M`)@2````````8``````````&`````@````@```````````````````!J````
M!`````(`````````^!(```````#X$@```````*`"````````!0`````````(
M`````````!@`````````=`````0```!"`````````)@5````````F!4`````
M``"@!0````````4````5````"``````````8`````````'X````!````!@``
M```````X&P```````#@;````````&`````````````````````0`````````
M``````````!Y`````0````8`````````4!L```````!0&P```````.`#````
M```````````````0````````````````````A`````$````&`````````$`?
M````````0!\```````!<-```````````````````0```````````````````
M`(H````!````!@````````"<4P```````)Q3````````%```````````````
M``````0```````````````````"0`````0````(`````````L%,```````"P
M4P```````%)````````````````````(````````````````````F`````$`
M```"``````````24````````!)0```````#\````````````````````!```
M`````````````````*8````!`````@``````````E0````````"5````````
M"`8```````````````````@```````````````````"P````#@````,`````
M````")L!```````(FP````````@````````````````````(``````````@`
M````````O`````\````#`````````!";`0``````$)L````````(````````
M````````````"``````````(`````````,@````&`````P`````````8FP$`
M`````!B;````````$`(````````&``````````@`````````$`````````#1
M`````0````,`````````*)T!```````HG0```````'@"````````````````
M```(``````````@`````````U@````$````#``````````"@`0```````*``
M``````"`````````````````````"````````````````````-P````(````
M`P````````"`H`$``````("@````````*!````````````````````@`````
M``````````````#A`````0```#````````````````````"`H````````"8`
M```````````````````!``````````$``````````0````,`````````````
M````````````IJ````````#J`````````````````````0``````````````
$````````
